ExceptionHelper class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
handle({required Future action(), bool needFirebaseAuthException = true, bool needFirebaseException = true, bool needPlatformException = true, bool needFormatException = true})
→ Future<void>
-